PAWpySeed: pawpyseed.core.projector Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Classes | Functions | Variables
pawpyseed.core.projector Namespace Reference

Defines the Projector class, an extension of the Wavefunction class for evaluating AE projection operators. More...

## Classes
class | CopyPseudoWavefunction
class | Projector

## Functions
def | make_c_ops (op_nums, symmops)
def | copy_wf (rwf, wf_ptr, allkpts, weights, setup_projectors=False, free_ref=False)

## Variables
int | OPSIZE = 9

## Detailed Description

Defines the Projector class, an extension of the Wavefunction class for evaluating AE projection operators.

## Function Documentation

def pawpyseed.core.projector.copy_wf | ( |  | rwf,
|  |  | wf_ptr,
|  |  | allkpts,
|  |  | weights,
|  |  | setup_projectors = `False`,
|  |  | free_ref = `False`
| ) |  |

def pawpyseed.core.projector.make_c_ops | ( |  | op_nums,
|  |  | symmops
| ) |  |

## Variable Documentation

int pawpyseed.core.projector.OPSIZE = 9